@@ -1,9 +1,8 @@
 ;;; mmm-utils.el --- Coding Utilities for MMM Mode
 
-;; Copyright (C) 2000 by Michael Abraham Shulman
+;; Copyright (C) 2000-2003, 2011-2013  Free Software Foundation, Inc.
 
-;; Author: Michael Abraham Shulman <viritrilbia@users.sourceforge.net>
-;; Version: $Id: mmm-utils.el,v 1.14 2003/03/09 17:04:04 viritrilbia Exp $
+;; Author: Michael Abraham Shulman <viritrilbia@gmail.com>
 
 ;;{{{ GPL
 
@@ -31,8 +30,6 @@
 
 ;;; Code:
 
-(require 'cl)
-
 ;;{{{ Valid Buffer
 
 ;; We used to wrap almost everything in this, but I realized that
@@ -46,9 +43,7 @@ means not hidden, not a minibuffer, not in batch mode, and not in of
                (window-minibuffer-p (selected-window))
                (memq major-mode mmm-never-modes)
                noninteractive
-               ;; Unnecessary as now hidden
-;;;               (equal (buffer-name) mmm-temp-buffer-name)
-               )
+               mmm-in-temp-buffer)
      ,@body))
 
 ;;;(def-edebug-spec mmm-valid-buffer t)
@@ -78,7 +73,11 @@ substituted for the corresponding REGEXP wherever it matches."
     (save-match-data
       (dolist (pair arg-pairs)
         (while (string-match (car pair) string)
-          (setq string (replace-match (cdr pair) t t string))))))
+          (setq string (replace-match
+                        (if (fboundp 'format-mode-line)
+                            (format-mode-line (cdr pair))
+                          (cdr pair))
+                        t t string))))))
   string)
 
 (defun mmm-format-matches (string &optional on-string)
@@ -93,7 +92,7 @@ ON-STRING, if supplied, means to use the match data from a
           subexp)
       (save-match-data
         (while (string-match "~\\([0-9]\\)" string)
-          (setq subexp (string-to-int (match-string-no-properties 1 string))
+          (setq subexp (string-to-number (match-string-no-properties 1 string))
                 string (replace-match
 			(save-match-data
 			  (set-match-data old-data)
@@ -118,7 +117,7 @@ is important that nil values disappear."
 Use of this macro can make code more readable when there are a lot of
 PARAMS, but less readable when there are only a few. Also best used
 only when it is important that nil values disappear."
-  `(append ,@(mapcar #'(lambda (param)
+  `(append ,@(mapcar (lambda (param)
                          (macroexpand `(mmm-save-keyword ,param)))
                      params)))
 
@@ -155,4 +154,4 @@ i.e. whether text inserted at the marker should be inside the region."
 
 (provide 'mmm-utils)
 
-;;; mmm-utils.el ends here
\ No newline at end of file
+;;; mmm-utils.el ends here
